Index: OpenSceneGraph/trunk/examples/osgthirdpersonview/osgthirdpersonview.cpp
===================================================================
--- OpenSceneGraph/trunk/examples/osgthirdpersonview/osgthirdpersonview.cpp (revision 12292)
+++ OpenSceneGraph/trunk/examples/osgthirdpersonview/osgthirdpersonview.cpp (revision 12529)
@@ -33,5 +33,5 @@
 //
 // Command line arguments are taken to be models for display. If you
 // specify no command line arguments, the code attempts to load cow.osg.
 
 
@@ -148,6 +148,6 @@
         // User didn't specify anything, or file(s) didn't exist.
         // Try to load the cow...
-        osg::notify( osg::WARN ) << arguments.getApplicationName() << ": Could not find specified files. Trying \"cow.osg\" instead." << std::endl;
-        if ( !(scene = osgDB::readNodeFile( std::string( "cow.osg" ) ) ) )
+        osg::notify( osg::WARN ) << arguments.getApplicationName() << ": Could not find specified files. Trying \"cow.osgt\" instead." << std::endl;
+        if ( !(scene = osgDB::readNodeFile( std::string( "cow.osgt" ) ) ) )
         {
             osg::notify( osg::FATAL ) << arguments.getApplicationName() << ": No data loaded." << std::endl;
@@ -33,5 +33,5 @@
 //
 // Command line arguments are taken to be models for display. If you
-// specify no command line arguments, the code attempts to load cow.osg.
+// specify no command line arguments, the code attempts to load cow.osgt.
 
 
